@@ -21,8 +21,8 @@
 //! Add `layeredconf`, `clap`, and `serde` to your `Cargo.toml`
 //!
 //! ```toml
-//! [dependancies]
-//! layeredconf = "0.1.4"
+//! [dependencies]
+//! layeredconf = "0.2.1"
 //! clap = "3.0.0-beta.5"
 //! serde = { version = "1.0", features = ["derive"] }
 //! ```
@@ -132,7 +132,12 @@ pub enum Error {
     AutoFormatFailed,
     /// A file was loaded in two Layers
     #[error("Loop detected loading config files")]
-    LoopingLoadConfig,
+    LoopingLoadConfig {
+        /// Parent sources
+        parents: Vec<Source>,
+        /// Path that failed
+        path: PathBuf,
+    },
     /// Path canonicalization failed
     #[error("Path canonicalization error {wrapped:?} for {path:?}")]
     PathCanonicalization {
@@ -141,6 +146,24 @@ pub enum Error {
         /// Path that failed
         path: PathBuf,
     },
+    /// File not found
+    #[error("File not found {path:?}")]
+    FileNotFound {
+        /// Path that failed
+        path: PathBuf,
+    },
+    /// Error getting current directory
+    #[error("Error getting current directory {wrapped:?}")]
+    CurrentDir {
+        /// Wrapped io::Error
+        wrapped: std::io::Error,
+    },
+    /// Error getting parent directory
+    #[error("Error getting parent directory {path:?}")]
+    ParentDir {
+        /// Path that failed
+        path: PathBuf,
+    },
     /// File I/O error
     #[error("I/O Error {wrapped:?} for {path:?}")]
     IoError {
@@ -170,16 +193,22 @@ pub enum Error {
 }
 
 pub(crate) fn map_io_error(path: &'_ Path) -> impl Fn(std::io::Error) -> Error + '_ {
-    move |wrapped| Error::IoError {
-        wrapped,
-        path: path.to_path_buf(),
+    move |wrapped| {
+        let path = path.to_path_buf();
+        match wrapped.kind() {
+            std::io::ErrorKind::NotFound => Error::FileNotFound { path },
+            _ => Error::IoError { wrapped, path },
+        }
     }
 }
 
 pub(crate) fn map_canonicalization_error(path: &'_ Path) -> impl Fn(std::io::Error) -> Error + '_ {
-    move |wrapped| Error::IoError {
-        wrapped,
-        path: path.to_path_buf(),
+    move |wrapped| {
+        let path = path.to_path_buf();
+        match wrapped.kind() {
+            std::io::ErrorKind::NotFound => Error::FileNotFound { path },
+            _ => Error::PathCanonicalization { path, wrapped },
+        }
     }
 }
 
